pub struct CollectedClientData {
pub typ: ClientDataType,
pub challenge: Vec<u8>,
pub origin: String,
}Expand description
Fields
typ: ClientDataTypechallenge: Vec<u8>origin: StringTrait Implementations
Sourceimpl Clone for CollectedClientData
impl Clone for CollectedClientData
Sourcefn clone(&self) -> CollectedClientData
fn clone(&self) -> CollectedClientData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CollectedClientData
impl Debug for CollectedClientData
Sourceimpl<'de> Deserialize<'de> for CollectedClientData
impl<'de> Deserialize<'de> for CollectedClientData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CollectedClientData
impl JsonSchema for CollectedClientData
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CollectedClientData
impl RefUnwindSafe for CollectedClientData
impl Send for CollectedClientData
impl Sync for CollectedClientData
impl Unpin for CollectedClientData
impl UnsafeUnpin for CollectedClientData
impl UnwindSafe for CollectedClientData