Struct P256CompressedPublicKey
#[repr(transparent)]pub struct P256CompressedPublicKey(pub <P256 as Curve>::PublicKey);Expand description
Compressed public key, i.e. x coordinate with leading SEC1 tag byte
Tuple Fields
0: <P256 as Curve>::PublicKeyTrait Implementations
impl<'arbitrary> Arbitrary<'arbitrary> for P256CompressedPublicKey
impl<'arbitrary> Arbitrary<'arbitrary> for P256CompressedPublicKey
fn arbitrary(
u: &mut Unstructured<'arbitrary>,
) -> Result<P256CompressedPublicKey, Error>
fn arbitrary( u: &mut Unstructured<'arbitrary>, ) -> Result<P256CompressedPublicKey, Error>
Generate an arbitrary value of
Self from the given unstructured data. Read morefn arbitrary_take_rest(
u: Unstructured<'arbitrary>,
) -> Result<P256CompressedPublicKey, Error>
fn arbitrary_take_rest( u: Unstructured<'arbitrary>, ) -> Result<P256CompressedPublicKey, Error>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreimpl BorshDeserialize for P256CompressedPublicKey
impl BorshDeserialize for P256CompressedPublicKey
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<P256CompressedPublicKey, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSerialize for P256CompressedPublicKey
impl BorshSerialize for P256CompressedPublicKey
impl Clone for P256CompressedPublicKey
impl Clone for P256CompressedPublicKey
fn clone(&self) -> P256CompressedPublicKey
fn clone(&self) -> P256CompressedPublicKey
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for P256CompressedPublicKey
impl Debug for P256CompressedPublicKey
impl<'de> Deserialize<'de> for P256CompressedPublicKey
impl<'de> Deserialize<'de> for P256CompressedPublicKey
fn deserialize<__D>(
deserializer: __D,
) -> Result<P256CompressedPublicKey, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
deserializer: __D,
) -> Result<P256CompressedPublicKey, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Display for P256CompressedPublicKey
impl Display for P256CompressedPublicKey
impl FromStr for P256CompressedPublicKey
impl FromStr for P256CompressedPublicKey
impl Hash for P256CompressedPublicKey
impl Hash for P256CompressedPublicKey
impl Ord for P256CompressedPublicKey
impl Ord for P256CompressedPublicKey
fn cmp(&self, other: &P256CompressedPublicKey) -> Ordering
fn cmp(&self, other: &P256CompressedPublicKey) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
impl PartialEq for P256CompressedPublicKey
impl PartialEq for P256CompressedPublicKey
impl PartialOrd for P256CompressedPublicKey
impl PartialOrd for P256CompressedPublicKey
impl Serialize for P256CompressedPublicKeywhere
P256CompressedPublicKey: Display,
impl Serialize for P256CompressedPublicKeywhere
P256CompressedPublicKey: Display,
fn serialize<__S>(
&self,
serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for P256CompressedPublicKey
impl Eq for P256CompressedPublicKey
impl StructuralPartialEq for P256CompressedPublicKey